@@ -6,10 +6,10 @@ arg_name <- function(quos, index) {
   name
 }
 
-cnd_bullet_cur_group_label <- function() {
+cnd_bullet_cur_group_label <- function(what = "error") {
   label <- cur_group_label()
   if (label != "") {
-    glue("The error occurred in {label}.")
+    glue("The {what} occurred in {label}.")
   }
 }
 
