@@ -225,10 +225,7 @@ mutate_cols <- function(.data, ...) {
   on.exit(mask$forget("mutate"), add = TRUE)
 
   rows <- mask$get_rows()
-
-  dots <- enquos(...)
-  dots_names <- names(dots)
-  auto_named_dots <- names(enquos(..., .named = TRUE))
+  dots <- dplyr_quosures(...)
   if (length(dots) == 0L) {
     return(NULL)
   }
@@ -237,90 +234,108 @@ mutate_cols <- function(.data, ...) {
 
   withCallingHandlers({
     for (i in seq_along(dots)) {
-      not_named <- (is.null(dots_names) || dots_names[i] == "")
-
-      # a list in which each element is the result of
-      # evaluating the quosure in the "sliced data mask"
-      # recycling it appropriately to match the group size
-      #
-      # TODO: reinject hybrid evaluation at the R level
-      chunks <- NULL
-
-      # result after unchopping the chunks
-      result <- NULL
-
-      if (quo_is_symbol(dots[[i]]) ){
-        name <- as_string(quo_get_expr(dots[[i]]))
-
-        if (name %in% names(new_columns)) {
-          # already have result and chunks
-          result <- new_columns[[name]]
-          chunks <- mask$resolve(name)
-        } else if (name %in% names(.data)) {
-          # column from the original data
-          result <- .data[[name]]
-          chunks <- mask$resolve(name)
-        }
-
-        if (inherits(.data, "rowwise_df") && vec_is_list(result)) {
-          sizes <- list_sizes(result)
-          wrong <- which(sizes != 1)
-          if (length(wrong)) {
-            # same error as would have been generated by mask$eval_all_mutate()
-            group <- wrong[1L]
-            mask$set_current_group(group)
-            abort(x_size = sizes[group], class = "dplyr:::mutate_incompatible_size")
-          }
-        }
-      }
-
-      # evaluate the chunks if needed
-      if (is.null(chunks)) {
-        chunks <- mask$eval_all_mutate(dots[[i]])
-      }
-
       mask$across_cache_reset()
 
-      if (is.null(chunks)) {
-        if (!is.null(dots_names) && dots_names[i] != "") {
-          new_columns[[dots_names[i]]] <- zap()
-          mask$remove(dots_names[i])
-        }
-        next
-      }
+      # get results from all the quosures that are expanded from ..i
+      # then ingest them after
+      quosures <- expand_quosure(dots[[i]])
+      quosures_results <- vector(mode = "list", length = length(quosures))
 
-      # only unchop if needed
-      if (is.null(result)) {
-        if (length(rows) == 1) {
-          result <- chunks[[1]]
-        } else {
-          result <- withCallingHandlers(
-            vec_unchop(chunks <- vec_cast_common(!!!chunks), rows),
-            vctrs_error_incompatible_type = function(cnd) {
-              abort(class = "dplyr:::error_mutate_incompatible_combine", parent = cnd)
+      for (k in seq_along(quosures)) {
+        quo <- quosures[[k]]
+        quo_data <- attr(quo, "dplyr:::data")
+        context_poke("column", quo_data$column)
+
+        # a list in which each element is the result of
+        # evaluating the quosure in the "sliced data mask"
+        # recycling it appropriately to match the group size
+        #
+        # TODO: reinject hybrid evaluation at the R level
+        chunks <- NULL
+
+        # result after unchopping the chunks
+        result <- NULL
+
+        if (quo_is_symbol(quo)){
+          name <- as_string(quo_get_expr(quo))
+
+          if (name %in% names(new_columns)) {
+            # already have result and chunks
+            result <- new_columns[[name]]
+            chunks <- mask$resolve(name)
+          } else if (name %in% names(.data)) {
+            # column from the original data
+            result <- .data[[name]]
+            chunks <- mask$resolve(name)
+          }
+
+          if (inherits(.data, "rowwise_df") && vec_is_list(result)) {
+            sizes <- list_sizes(result)
+            wrong <- which(sizes != 1)
+            if (length(wrong)) {
+              # same error as would have been generated by mask$eval_all_mutate()
+              group <- wrong[1L]
+              mask$set_current_group(group)
+              abort(x_size = sizes[group], class = "dplyr:::mutate_incompatible_size")
             }
-          )
+          }
         }
+
+        if (is.null(chunks)) {
+          chunks <- mask$eval_all_mutate(quo)
+        }
+
+        if (is.null(chunks)) {
+          next
+        }
+
+        # only unchop if needed
+        if (is.null(result)) {
+          if (length(rows) == 1) {
+            result <- chunks[[1]]
+          } else {
+            result <- withCallingHandlers(
+              vec_unchop(chunks <- vec_cast_common(!!!chunks), rows),
+              vctrs_error_incompatible_type = function(cnd) {
+                abort(class = "dplyr:::error_mutate_incompatible_combine", parent = cnd)
+              }
+            )
+          }
+        }
+
+        quosures_results[[k]] <- list(result = result, chunks = chunks)
       }
 
-      if (not_named && is.data.frame(result)) {
-        new_columns[names(result)] <- result
 
-        # remember each result separately
-        map2(seq_along(result), names(result), function(i, nm) {
-          mask$add(nm, pluck(chunks, i))
-        })
-      } else {
-        name <- if (not_named) auto_named_dots[i] else dots_names[i]
+      for (k in seq_along(quosures)) {
+        quo <- quosures[[k]]
+        quo_data <- attr(quo, "dplyr:::data")
 
-        # treat as a single output otherwise
-        new_columns[[name]] <- result
+        quo_result <- quosures_results[[k]]
+        if (is.null(quo_result)) {
+          if (quo_data$is_named) {
+            name <- quo_data$name_given
+            new_columns[[name]] <- zap()
+            mask$remove(name)
+          }
+          next
+        }
+
+        result <- quo_result$result
+        chunks <- quo_result$chunks
+
+        if (!quo_data$is_named && is.data.frame(result)) {
+          new_columns[names(result)] <- result
+          mask$add_many(result, chunks)
+        } else {
+          # treat as a single output otherwise
+          name <- quo_data$name_auto
+          new_columns[[name]] <- result
+          mask$add_one(name, chunks)
+        }
 
-        # remember
-        mask$add(name, chunks)
       }
 
-
     }
 
   },
@@ -384,17 +399,24 @@ mutate_cols <- function(.data, ...) {
 
   },
   warning = function(w) {
+    # Check if there is an upstack calling handler that would muffle
+    # the warning. This avoids doing the expensive work below for a
+    # silenced warning (#5675).
+    if (check_muffled_warning(w)) {
+      maybe_restart("muffleWarning")
+    }
+
     local_call_step(dots = dots, .index = i, .fn = "mutate")
 
     warn(c(
       cnd_bullet_header(),
       i = conditionMessage(w),
       i = cnd_bullet_input_info(),
-      i = cnd_bullet_cur_group_label()
+      i = cnd_bullet_cur_group_label(what = "warning")
     ))
 
-    # cancel `w`
-    invokeRestart("muffleWarning")
+    # Cancel `w`
+    maybe_restart("muffleWarning")
   })
 
   is_zap <- map_lgl(new_columns, inherits, "rlang_zap")
@@ -404,3 +426,35 @@ mutate_cols <- function(.data, ...) {
   attr(new_columns, "used") <- used
   new_columns
 }
+
+check_muffled_warning <- function(cnd) {
+  early_exit <- TRUE
+
+  # Cancel early exits, e.g. from an exiting handler. This way we can
+  # still instrument caught warnings to avoid confusing
+  # inconsistencies. This doesn't work on versions of R older than
+  # 3.5.0 because they don't include this change:
+  # https://github.com/wch/r-source/commit/688eaebf. So with
+  # `tryCatch(warning = )`, the original warning `cnd` will be caught
+  # instead of the instrumented warning.
+  on.exit(
+    if (can_return_from_exit && early_exit) {
+      return(FALSE)
+    }
+  )
+
+  muffled <- withRestarts(
+    muffleWarning = function(...) TRUE,
+    {
+      signalCondition(cnd)
+      FALSE
+    }
+  )
+
+  early_exit <- FALSE
+  muffled
+}
+
+on_load(
+  can_return_from_exit <- getRversion() >= "3.5.0"
+)
