@@ -208,9 +208,7 @@ summarise_cols <- function(.data, ...) {
   mask <- DataMask$new(.data, caller_env())
   on.exit(mask$forget("summarise"), add = TRUE)
 
-  dots <- enquos(...)
-  dots_names <- names(dots)
-  auto_named_dots <- names(enquos(..., .named = TRUE))
+  dots <- dplyr_quosures(...)
 
   cols <- list()
 
@@ -218,36 +216,69 @@ summarise_cols <- function(.data, ...) {
   chunks <- vector("list", length(dots))
   types <- vector("list", length(dots))
 
+  chunks <- list()
+  types <- list()
+  out_names <- character()
+
   withCallingHandlers({
-    # generate all chunks and monitor the sizes
     for (i in seq_along(dots)) {
-      quo <- dots[[i]]
-
-      # a list in which each element is the result of
-      # evaluating the quosure in the "sliced data mask"
-      #
-      # TODO: reinject hybrid evaluation at the R level
-      chunks[[i]] <- mask$eval_all_summarise(quo)
-
       mask$across_cache_reset()
 
-      result_type <- types[[i]] <- withCallingHandlers(
-        vec_ptype_common(!!!chunks[[i]]),
-        vctrs_error_incompatible_type = function(cnd) {
-          abort(class = "dplyr:::error_summarise_incompatible_combine", parent = cnd)
+      quosures <- expand_quosure(dots[[i]])
+      quosures_results <- vector(mode = "list", length = length(quosures))
+
+      # with the previous part above, for each element of ... we can
+      # have either one or several quosures, each of them handled here:
+      for (k in seq_along(quosures)) {
+        quo <- quosures[[k]]
+        quo_data <- attr(quo, "dplyr:::data")
+        context_poke("column", quo_data$column)
+
+        chunks_k <- mask$eval_all_summarise(quo)
+        if (is.null(chunks_k)) {
+          next
         }
-      )
 
-      chunks[[i]] <- vec_cast_common(!!!chunks[[i]], .to = result_type)
+        types_k <- withCallingHandlers(
+          vec_ptype_common(!!!chunks_k),
+          vctrs_error_incompatible_type = function(cnd) {
+            abort(class = "dplyr:::error_summarise_incompatible_combine", parent = cnd)
+          }
+        )
+        chunks_k <- vec_cast_common(!!!chunks_k, .to = types_k)
+
+        quosures_results[[k]] <- list(chunks = chunks_k, types = types_k)
+      }
+
+      for (k in seq_along(quosures)) {
+        quo <- quosures[[k]]
+        quo_data <- attr(quo, "dplyr:::data")
+
+        quo_result <- quosures_results[[k]]
+        if (is.null(quo_result)) {
+          next
+        }
+        types_k <- quo_result$types
+        chunks_k <- quo_result$chunks
+
+        if (!quo_data$is_named && is.data.frame(types_k)) {
+          chunks_extracted <- .Call(dplyr_extract_chunks, chunks_k, types_k)
+
+          walk2(chunks_extracted, names(types_k), function(chunks_k_j, nm) {
+            mask$add_one(nm, chunks_k_j)
+          })
+
+          chunks <- append(chunks, chunks_extracted)
+          types <- append(types, as.list(types_k))
+          out_names <- c(out_names, names(types_k))
+        } else {
+          name <- quo_data$name_auto
+          mask$add_one(name, chunks_k)
+          chunks <- append(chunks, list(chunks_k))
+          types <- append(types, list(types_k))
+          out_names <- c(out_names, name)
+        }
 
-      if ((is.null(dots_names) || dots_names[i] == "") && is.data.frame(result_type)) {
-        # remember each result separately
-        map2(seq_along(result_type), names(result_type), function(j, nm) {
-          mask$add(nm, pluck(chunks[[i]], j))
-        })
-      } else {
-        # remember
-        mask$add(auto_named_dots[i], chunks[[i]])
       }
     }
 
@@ -256,14 +287,9 @@ summarise_cols <- function(.data, ...) {
     sizes <- recycle_info$sizes
 
     # materialize columns
-    for (i in seq_along(dots)) {
+    for (i in seq_along(chunks)) {
       result <- vec_c(!!!chunks[[i]], .ptype = types[[i]])
-
-      if ((is.null(dots_names) || dots_names[i] == "") && is.data.frame(result)) {
-        cols[names(result)] <- result
-      } else {
-        cols[[ auto_named_dots[i] ]] <- result
-      }
+      cols[[ out_names[i] ]] <- result
     }
 
   },
@@ -273,8 +299,10 @@ summarise_cols <- function(.data, ...) {
     )
     call_step <- peek_call_step()
     error_name <- call_step$error_name
+    show_group_details <- TRUE
 
     if (inherits(e, "dplyr:::error_summarise_incompatible_combine")) {
+      show_group_details <- FALSE
       bullets <- c(
         x = glue("Input `{error_name}` must return compatible vectors across groups", .envir = peek_call_step()),
         i = cnd_bullet_combine_details(e$parent$x, e$parent$x_arg),
@@ -293,22 +321,29 @@ summarise_cols <- function(.data, ...) {
         x = glue("Input `{error_name}` must be size {or_1(expected_size)}, not {size}.", expected_size = e$expected_size, size = e$size),
         i = glue("An earlier column had size {expected_size}.", expected_size = e$expected_size)
       )
+    } else if (inherits(e, "dplyr:::summarise_mixed_null")) {
+      show_group_details <- FALSE
+      bullets <- c(
+        x = glue("`{error_name}` must return compatible vectors across groups."),
+        i = "Cannot combine NULL and non NULL results."
+      )
     } else {
       bullets <- c(
         x = conditionMessage(e)
       )
     }
 
-    bullets <- c(cnd_bullet_header(), bullets, i = cnd_bullet_input_info())
-    if (!inherits(e, "dplyr:::error_summarise_incompatible_combine")) {
-      bullets <- c(bullets, i = cnd_bullet_cur_group_label())
-    }
-
+    bullets <- c(
+      cnd_bullet_header(),
+      bullets,
+      i = cnd_bullet_input_info(),
+      i = if (show_group_details) cnd_bullet_cur_group_label()
+    )
     abort(bullets, class = "dplyr_error")
 
   })
 
-  list(new = cols, size = sizes, all_one = identical(sizes ,1L))
+  list(new = cols, size = sizes, all_one = identical(sizes, 1L))
 }
 
 summarise_build <- function(.data, cols) {
