@@ -1,5 +1,3 @@
-context("count-tally")
-
 # count -------------------------------------------------------------------
 
 test_that("informs if n column already present, unless overridden", {
@@ -71,13 +69,10 @@ test_that("works with dbplyr", {
 })
 
 test_that("can only explicitly chain together multiple tallies", {
-  verify_output(test_path("test-count-tally.txt"), {
-    df <- data.frame(g = c(1, 1, 2, 2), n = 1:4)
-    df %>% count(g, wt = n)
-    df %>% count(g, wt = n) %>% count(wt = n)
-
-    df %>% count(n)
-  })
+  df <- data.frame(g = c(1, 1, 2, 2), n = 1:4)
+  expect_snapshot(df %>% count(g, wt = n))
+  expect_snapshot(df %>% count(g, wt = n) %>% count(wt = n))
+  expect_snapshot(df %>% count(n))
 })
 
 test_that("wt = n() is deprecated", {
