@@ -1,5 +1,3 @@
-context("Mutate")
-
 test_that("empty mutate returns input", {
   df <- tibble(x = 1)
   gf <- group_by(df, x)
@@ -177,8 +175,8 @@ test_that("mutate preserves grouping", {
 test_that("mutate works on zero-row grouped data frame (#596)", {
   dat <- data.frame(a = numeric(0), b = character(0), stringsAsFactors = TRUE)
   res <- dat %>% group_by(b, .drop = FALSE) %>% mutate(a2 = a * 2)
-  expect_is(res$a2, "numeric")
-  expect_is(res, "grouped_df")
+  expect_type(res$a2, "double")
+  expect_s3_class(res, "grouped_df")
   expect_equal(res$a2, numeric(0))
 
   expect_type(group_rows(res), "list")
@@ -189,8 +187,8 @@ test_that("mutate works on zero-row grouped data frame (#596)", {
 test_that("mutate works on zero-row rowwise data frame (#4224)", {
   dat <- data.frame(a = numeric(0))
   res <- dat %>% rowwise() %>% mutate(a2 = a * 2)
-  expect_is(res$a2, "numeric")
-  expect_is(res, "rowwise_df")
+  expect_type(res$a2, "double")
+  expect_s3_class(res, "rowwise_df")
   expect_equal(res$a2, numeric(0))
 })
 
@@ -265,7 +263,7 @@ test_that("mutate coerces results from one group with all NA values (#1463) ", {
   df <- tibble(x = c(1, 2), y = c(1, NA))
   res <- df %>% group_by(x) %>% mutate(z = ifelse(y > 1, 1, 2))
   expect_true(is.na(res$z[2]))
-  expect_is(res$z, "numeric")
+  expect_type(res$z, "double")
 })
 
 test_that("grouped subsets are not lazy (#3360)", {
@@ -449,77 +447,109 @@ test_that("mutate() casts data frame results to common type (#5646)", {
   expect_equal(res$z, c(NA, 2))
 })
 
+test_that("can suppress or catch warnings from the outside (#5675)", {
+  # Check that basic warning handling still works
+  expect_no_warning(
+    suppressWarnings(mutate(tibble(), warning("foo")))
+  )
+
+  f <- function() warn("foo", "dplyr:::foo")
+  x <- tryCatch(warning = identity, mutate(mtcars, f()))
+  msg <- conditionMessage(x)
+  expect_match(msg, "foo")
+
+  # Check that caught warnings are instrumented. Requires
+  # <https://github.com/wch/r-source/commit/688eaebf>.
+  if (can_return_from_exit) {
+    expect_match(msg, "Problem with")
+  }
+})
 
 # Error messages ----------------------------------------------------------
 
 test_that("mutate() give meaningful errors", {
-  verify_output(test_path("test-mutate-errors.txt"), {
-    tbl <- tibble(x = 1:2, y = 1:2)
+  tbl <- tibble(x = 1:2, y = 1:2)
 
-    "# setting column to NULL makes it unavailable"
-    tbl %>%
-      mutate(y = NULL, a = sum(y))
-    tbl %>%
-      group_by(x) %>%
-      mutate(y = NULL, a = sum(y))
+  # setting column to NULL makes it unavailable
+  expect_snapshot(error = TRUE, tbl %>% mutate(y = NULL, a = sum(y)))
+  expect_snapshot(error = TRUE, tbl %>%
+    group_by(x) %>%
+    mutate(y = NULL, a = sum(y))
+  )
 
-    "# incompatible column type"
-    tibble(x = 1) %>%
-      mutate(y = mean)
+  # incompatible column type
+  expect_snapshot(error = TRUE, tibble(x = 1) %>% mutate(y = mean))
 
-    "# Unsupported type"
-    df <- tibble(g = c(1, 1, 2, 2, 2), x = 1:5)
-    df %>%
-        mutate(out = env(a = 1))
-    df %>%
-      group_by(g) %>%
-      mutate(out = env(a = 1))
-    df %>%
-      rowwise() %>%
-      mutate(out = rnorm)
+  # Unsupported type"
+  df <- tibble(g = c(1, 1, 2, 2, 2), x = 1:5)
+  expect_snapshot(error = TRUE, df %>% mutate(out = env(a = 1)))
+  expect_snapshot(error = TRUE, df %>%
+    group_by(g) %>%
+    mutate(out = env(a = 1))
+  )
+  expect_snapshot(error = TRUE, df %>%
+    rowwise() %>%
+    mutate(out = rnorm)
+  )
 
-    "# incompatible types across groups"
+  # incompatible types across groups
+  expect_snapshot(error = TRUE,
     data.frame(x = rep(1:5, each = 3)) %>%
       group_by(x) %>%
       mutate(val = ifelse(x < 3, "foo", 2))
+  )
 
+  expect_snapshot(error = TRUE,
     tibble(a = 1:3, b=4:6) %>%
       group_by(a) %>%
       mutate(if(a==1) NULL else "foo")
+  )
 
-    "# incompatible size"
-    data.frame(x = c(2, 2, 3, 3)) %>%
-      mutate(int = 1:5)
+  # incompatible size
+  expect_snapshot(error = TRUE,
+    data.frame(x = c(2, 2, 3, 3)) %>% mutate(int = 1:5)
+  )
+  expect_snapshot(error = TRUE,
     data.frame(x = c(2, 2, 3, 3)) %>%
       group_by(x) %>%
       mutate(int = 1:5)
+  )
+  expect_snapshot(error = TRUE,
     data.frame(x = c(2, 3, 3)) %>%
       group_by(x) %>%
       mutate(int = 1:5)
+  )
+  expect_snapshot(error = TRUE,
     data.frame(x = c(2, 2, 3, 3)) %>%
       rowwise() %>%
       mutate(int = 1:5)
+  )
+  expect_snapshot(error = TRUE,
     tibble(y = list(1:3, "a")) %>%
       rowwise() %>%
       mutate(y2 = y)
-    data.frame(x = 1:10) %>%
-      mutate(y = 11:20, y = 1:2)
+  )
+  expect_snapshot(error = TRUE,
+    data.frame(x = 1:10) %>% mutate(y = 11:20, y = 1:2)
+  )
 
-    "# .data pronoun"
-    tibble(a = 1) %>%
-      mutate(c = .data$b)
+  # .data pronoun
+  expect_snapshot(error = TRUE,
+    tibble(a = 1) %>% mutate(c = .data$b)
+  )
+  expect_snapshot(error = TRUE,
     tibble(a = 1:3) %>%
       group_by(a) %>%
       mutate(c = .data$b)
+  )
 
-    "# obsolete data mask"
-    lazy <- function(x) list(enquo(x))
-    res <- tbl %>%
-      rowwise() %>%
-      mutate(z = lazy(x), .keep = "unused")
-    eval_tidy(res$z[[1]])
+  # obsolete data mask
+  lazy <- function(x) list(enquo(x))
+  res <- tbl %>%
+    rowwise() %>%
+    mutate(z = lazy(x), .keep = "unused")
+  expect_snapshot(error = TRUE, eval_tidy(res$z[[1]]))
 
-    "# Error that contains {"
-    tibble() %>% mutate(stop("{"))
-  })
+  # Error that contains {
+  expect_snapshot(error = TRUE, tibble() %>% mutate(stop("{")))
 })
