@@ -1,5 +1,3 @@
-context("Window functions")
-
 test_that("If n = 0, lead and lag return x", {
   expect_equal(lead(1:2, 0), 1:2)
   expect_equal(lag(1:2, 0), 1:2)
@@ -87,6 +85,14 @@ test_that("cummean is not confused by FP error (#1387)", {
   expect_true(all(cummean(a) == a))
 })
 
+test_that("cummean is consistent with cumsum() and seq_along() (#5287)", {
+  x <- 1:5
+  expect_equal(cummean(x), c(1, 1.5, 2, 2.5, 3))
+  expect_equal(cummean(x), cumsum(x) / seq_along(x))
+
+  expect_equal(cummean(numeric()), numeric())
+})
+
 test_that("order_by() returns correct value", {
   expected <- int(15, 14, 12, 9, 5)
   expect_identical(order_by(5:1, cumsum(1:5)), expected)
@@ -109,7 +115,5 @@ test_that("order_by() works in arbitrary envs (#2297)", {
 })
 
 test_that("order_by() give meaningful errors", {
-  verify_output(test_path("test-window-errors.txt"), {
-    order_by(NULL, !!1L)
-  })
+  expect_snapshot(error = TRUE, order_by(NULL, !!1L))
 })
